
# In production, you'd want this to be set so something sensible:
from __future__ import print_function, unicode_literals, absolute_import, division
accounts.admin_email = 'admin@example.org'  
